@@ -12,7 +12,7 @@ class TypeRacerScraper:
         self.parsedSource = BeautifulSoup(self.source.content, "html.parser")
 
 
-    def result_dataframe(self):
+    def result_json(self):
         race     = []
         speed    = []
         accuracy = []
@@ -40,6 +40,3 @@ class TypeRacerScraper:
         return df.to_json(orient="split")
 
 
-# df = TypeRacerScraper("not_not_mk", "10").result_dataframe()
-# with open("s.json", "+w") as f:
-#   f.write(df)
